==> tecfy_core_package-1.0.23.tar.gz: lib/views/home/drawer.dart <==
part of tecfy_core_client_package;

class MainDrawer extends StatefulWidget {
  final dynamic selected;
  MainDrawer(this.selected);
  @override
  _MainDrawerState createState() => _MainDrawerState();
}

class _MainDrawerState extends State<MainDrawer> {
  static double _posstion = 0;
  late ScrollController _controller;

  @override
  void initState() {
    _controller = ScrollController();
    Future.delayed(Duration(milliseconds: 100)).then((_) {
      if (_controller.offset != _posstion) _controller.jumpTo(_posstion);
      _controller.addListener(() {
        _posstion = _controller.offset;
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Drawer(
      child: Column(
        children: <Widget>[
          UserAccountsDrawerHeader(
            accountEmail: Text(LocalConfigService.user?.email ?? '-'),
            accountName: Text(LocalConfigService.user?.fullName ?? '-'),
            otherAccountsPictures: <Widget>[
              StreamBuilder(
                  stream: ConnectionService.activeConnectionStream,
                  builder: (c, _) => ConnectionService.getConnectionIcon(c))
            ],
          ),
          Expanded(
            child: ListView(
                controller: LayoutService.isMobile(context)
                    ? ScrollController()
                    : _controller,
                children: (InitService.menuItems ?? [])
                    .map<Widget>((c) => c.subMenuItems != null
                        ? Column(
                            children: (c.subMenuItems
                                    ?.map<Widget>((e) => Container(
                                        decoration: BoxDecoration(
                                            color: e.title == widget.selected
                                                ? ThemeService
                                                    .backgroundSecondColor
                                                : Colors.white,
                                            borderRadius: BorderRadius.all(
                                                Radius.circular(5.0)),
                                            shape: BoxShape.rectangle),
                                        child: ListTile(
                                          title: Text(
                                            AppLocale.translate(
                                                context, e.title),
                                            style: TextStyle(
                                                fontWeight:
                                                    e.title == widget.selected
                                                        ? FontWeight.bold
                                                        : FontWeight.normal),
                                          ),
                                          onTap: () {
                                            if (e.title != widget.selected) {
                                              e.onClick?.call(context);
                                            }
                                          },
                                        )))
                                    .toList() ??
                                [])
                              ..insert(
                                  0,
                                  Align(
                                      alignment: LocalConfigService.isArabic
                                          ? Alignment.centerRight
                                          : Alignment.centerLeft,
                                      child: Padding(
                                          padding: EdgeInsets.only(left: 15),
                                          child: Text(
                                            AppLocale.translate(
                                                context, c.title),
                                            style: TextStyle(
                                                color: ThemeService
                                                    .backgroundSecondColor),
                                          )))),
                          )
                        : Column(
                            children: <Widget>[
                              Divider(),
                              ListTile(
                                title:
                                    Text(AppLocale.translate(context, c.title)),
                                onTap: c.onClick != null
                                    ? () => c.onClick?.call(context)
                                    : null,
                              )
                            ],
                          ))
                    .toList()),
          )
        ],
      ),
    );
  }
}

==> tecfy_core_package-1.0.46.tar.gz: lib/views/home/drawer.dart <==
part of tecfy_core_client_package;

class MainDrawer extends StatefulWidget {
  final dynamic selected;
  MainDrawer(this.selected);
  @override
  _MainDrawerState createState() => _MainDrawerState();
}

class _MainDrawerState extends State<MainDrawer> {
  static double _posstion = 0;
  late ScrollController _controller;

  @override
  void initState() {
    _controller = ScrollController();
    Future.delayed(Duration(milliseconds: 100)).then((_) {
      if (_controller.offset != _posstion) _controller.jumpTo(_posstion);
      _controller.addListener(() {
        _posstion = _controller.offset;
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Drawer(
      child: Column(
        children: <Widget>[
          UserAccountsDrawerHeader(
            accountEmail: Text(LocalConfigService.user?.email ?? '-'),
            accountName: Text(LocalConfigService.user?.fullName ?? '-'),
            otherAccountsPictures: <Widget>[
              StreamBuilder(
                  stream: ConnectionService.activeConnectionStream,
                  builder: (c, _) => ConnectionService.getConnectionIcon(c))
            ],
          ),
          Expanded(
            child: ListView(
                controller: LayoutService.isMobile(context)
                    ? ScrollController()
                    : _controller,
                children: (InitService.menuItems ?? [])
                    .map<Widget>((c) => c.subMenuItems != null
                        ? Column(
                            children: (c.subMenuItems
                                    ?.map<Widget>((e) => Container(
                                        decoration: BoxDecoration(
                                            color: e.title == widget.selected
                                                ? ThemeService
                                                    .backgroundSecondColor
                                                : Colors.white,
                                            borderRadius: BorderRadius.all(
                                                Radius.circular(5.0)),
                                            shape: BoxShape.rectangle),
                                        child: ListTile(
                                          title: Text(
                                            AppLocale.translate(e.title),
                                            style: TextStyle(
                                                fontWeight:
                                                    e.title == widget.selected
                                                        ? FontWeight.bold
                                                        : FontWeight.normal),
                                          ),
                                          onTap: () {
                                            if (e.title != widget.selected) {
                                              e.onClick?.call(context);
                                            }
                                          },
                                        )))
                                    .toList() ??
                                [])
                              ..insert(
                                  0,
                                  Align(
                                      alignment: LocalConfigService.isArabic
                                          ? Alignment.centerRight
                                          : Alignment.centerLeft,
                                      child: Padding(
                                          padding: EdgeInsets.only(left: 15),
                                          child: Text(
                                            AppLocale.translate(c.title),
                                            style: TextStyle(
                                                color: ThemeService
                                                    .backgroundSecondColor),
                                          )))),
                          )
                        : Column(
                            children: <Widget>[
                              Divider(),
                              ListTile(
                                title: Text(AppLocale.translate(c.title)),
                                onTap: c.onClick != null
                                    ? () => c.onClick?.call(context)
                                    : null,
                              )
                            ],
                          ))
                    .toList()),
          )
        ],
      ),
    );
  }
}
